@@ -1,17 +1,33 @@
 /*
-    SPDX-FileCopyrightText: 2012 Andrius da Costa Ribas <andriusmao@gmail.com>
+    Copyright 2012  Andrius da Costa Ribas <andriusmao@gmail.com>
 
-    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public
+    License as published by the Free Software Foundation; either
+    version 2.1 of the License, or (at your option) version 3, or any
+    later version accepted by the membership of KDE e.V. (or its
+    successor approved by the membership of KDE e.V.), which shall
+    act as a proxy defined in Section 6 of version 3 of the license.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU Lesser General Public License for more details.
+
+    You should have received a copy of the GNU Lesser General Public
+    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#pragma once
+#ifndef LIBKGAPI2_DRIVEREVISION_H
+#define LIBKGAPI2_DRIVEREVISION_H
 
-#include "kgapidrive_export.h"
-#include "object.h"
 #include "types.h"
+#include "object.h"
+#include "kgapidrive_export.h"
 
-#include <QString>
-#include <QUrl>
+#include <QtCore/QString>
+#include <QtCore/QUrl>
+#include <QtCore/QVariantMap>
 
 #include <QDateTime>
 
@@ -31,17 +47,13 @@ namespace Drive
  * @author Andrius da Costa Ribas <andriusmao@gmail.com>
  * @author Daniel Vrátil <dvratil@redhat.com>
  */
-class KGAPIDRIVE_EXPORT Revision : public KGAPI2::Object
+class KGAPIDRIVE_EXPORT Revision: public KGAPI2::Object
 {
-public:
+
+  public:
     explicit Revision();
     explicit Revision(const Revision &other);
-    ~Revision() override;
-    bool operator==(const Revision &other) const;
-    bool operator!=(const Revision &other) const
-    {
-        return !operator==(other);
-    }
+    virtual ~Revision();
 
     /**
      * @brief Returns the id of the revision.
@@ -118,7 +130,7 @@ public:
      *
      * This is only populated and can only be modified for Google Docs.
      *
-     * @param publishAuto
+     * @param publishedAuto
      */
     void setPublishAuto(bool publishAuto);
 
@@ -150,7 +162,7 @@ public:
      *
      * This is a map from the export format to URL.
      */
-    QMap<QString /* format */, QUrl /* url */> exportLinks() const;
+    QMap < QString /* format */, QUrl /* url */ > exportLinks() const;
 
     /**
      * @brief Returns the name of the last user to modify this revision.
@@ -187,7 +199,7 @@ public:
     static RevisionsList fromJSONFeed(const QByteArray &jsonData);
     static QByteArray toJSON(const RevisionPtr &revision);
 
-private:
+  private:
     class Private;
     Private *const d;
     friend class Private;
@@ -196,3 +208,5 @@ private:
 } /* namespace Drive */
 
 } /* namespace KGAPI2 */
+
+#endif // LIBKGAPI2_DRIVEREVISION_H
